@@ -48,6 +48,8 @@ GstDialogSignal signals[] = {
 	{ "connection_add",          "clicked",         G_CALLBACK (on_connection_add_clicked) },
 	{ "connection_delete",       "clicked",         G_CALLBACK (on_connection_delete_clicked) },
 	{ "connection_configure",    "clicked",         G_CALLBACK (on_connection_configure_clicked) },
+	{ "connection_activate",     "clicked",         G_CALLBACK (on_connection_activate_button_clicked) },
+	{ "connection_deactivate",   "clicked",         G_CALLBACK (on_connection_deactivate_button_clicked) },
 	{ "connection_def_gw_omenu", "changed",         G_CALLBACK (gst_dialog_modify_cb) },
 	{ "domain",                  "changed",         G_CALLBACK (gst_dialog_modify_cb) },
 /*	{ "ip",                      "changed",         G_CALLBACK (gst_dialog_modify_cb) },*/
@@ -56,6 +58,14 @@ GstDialogSignal signals[] = {
 	{ "statichost_add",          "clicked",         G_CALLBACK (gst_dialog_modify_cb) },
 	{ "statichost_delete",       "clicked",         G_CALLBACK (on_hosts_delete_clicked) },
 	{ "statichost_delete",       "clicked",         G_CALLBACK (gst_dialog_modify_cb) },
+	{ "dns_server_add_button",   "clicked",         G_CALLBACK (on_dns_search_add_button_clicked) },
+	{ "dns_server_add_button",   "clicked",         G_CALLBACK (gst_dialog_modify_cb) },
+	{ "search_domain_add_button","clicked",         G_CALLBACK (on_dns_search_add_button_clicked) },
+	{ "search_domain_add_button","clicked",         G_CALLBACK (gst_dialog_modify_cb) },
+	{ "dns_server_del_button",   "clicked",         G_CALLBACK (on_dns_search_del_button_clicked) },
+	{ "dns_server_del_button",   "clicked",         G_CALLBACK (gst_dialog_modify_cb) },
+	{ "search_domain_del_button","clicked",         G_CALLBACK (on_dns_search_del_button_clicked) },
+	{ "search_domain_del_button","clicked",         G_CALLBACK (gst_dialog_modify_cb) },
 
 /*	{ "dns_list",                "focus_in_event",  G_CALLBACK (update_hint) },*/
 /*	{ "search_list",             "focus_in_event",  G_CALLBACK (update_hint) },*/
@@ -67,18 +77,22 @@ GstDialogSignal signals[] = {
 	{ "network_connection_druid",        "cancel", G_CALLBACK (on_network_druid_hide) },
 	{ "network_connection_page1",        "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_page2",        "next",   G_CALLBACK (on_network_druid_page_next) },
+	{ "network_connection_wireless_page",  "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_other_page1",  "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_plip_page1",   "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_ppp_page1",    "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_ppp_page2",    "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_page_name",         "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_page2",        "back",   G_CALLBACK (on_network_druid_page_back) },
+	{ "network_connection_wireless_page",  "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_other_page1",  "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_plip_page1",  "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_ppp_page1",    "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_ppp_page2",    "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_page_name",    "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_page_finish",  "back",   G_CALLBACK (on_network_druid_page_back) },
+	{ "network_connection_wireless_device_entry", "changed", G_CALLBACK (on_network_druid_entry_changed) },
+	{ "network_connection_essid", "changed", G_CALLBACK (on_network_druid_entry_changed) },
 	{ "network_connection_other_config_type", "changed", G_CALLBACK (on_network_druid_config_type_changed) },
 	{ "network_connection_other_ip_address", "changed", G_CALLBACK (on_network_druid_entry_changed) },
 	{ "network_connection_other_ip_mask", "changed", G_CALLBACK (on_network_druid_entry_changed) },
@@ -97,45 +111,54 @@ GstDialogSignal signals[] = {
 	{ "network_profiles_button", "clicked", G_CALLBACK (on_network_profiles_button_clicked) },
 	{ "network_profile_new", "clicked", G_CALLBACK (on_network_profile_new_clicked) },
 	{ "network_profile_delete", "clicked", G_CALLBACK (on_network_profile_delete_clicked) },
+
+	/* Interface properties callbacks */
+	{ "connection_config_dialog", "delete_event", G_CALLBACK (on_connection_delete_event) },
+	{ "connection_cancel", "clicked", G_CALLBACK (on_connection_cancel_clicked) },
+	{ "connection_ok", "clicked", G_CALLBACK (on_connection_ok_clicked) },
+	{ "ppp_autodetect_modem", "clicked", G_CALLBACK (on_ppp_autodetect_modem_clicked) },
+	{ "ppp_volume", "format_value", G_CALLBACK (on_volume_format_value) },
+	{ "ip_address", "focus_out_event", G_CALLBACK (on_ip_address_focus_out) },
+	{ "ip_netmask", "focus_out_event", G_CALLBACK (on_ip_address_focus_out) },
+	{ "ppp_update_dns", "toggled", G_CALLBACK (on_ppp_update_dns_toggled) },
+	{ "connection_name", "changed", G_CALLBACK (on_connection_modified) },
+	{ "status_autoboot", "toggled", G_CALLBACK (on_connection_modified) },
+	{ "status_user", "toggled", G_CALLBACK (on_connection_modified) },
+	{ "wlan_essid", "changed", G_CALLBACK (on_connection_modified) },
+	{ "connection_config", "clicked", G_CALLBACK (on_connection_modified) },
+	{ "ip_address", "changed", G_CALLBACK (on_connection_modified) },
+	{ "ip_netmask", "changed", G_CALLBACK (on_connection_modified) },
+	{ "ip_gateway", "changed", G_CALLBACK (on_connection_modified) },
+	{ "ip_update_dns", "toggled", G_CALLBACK (on_connection_modified) },
+	{ "ptp_address", "changed", G_CALLBACK (on_connection_modified) },
+	{ "ptp_remote_address", "changed", G_CALLBACK (on_connection_modified) },
+	{ "ptp_remote_is_gateway", "toggled", G_CALLBACK (on_connection_modified) },
+	{ "ppp_serial_port", "changed", G_CALLBACK (on_connection_modified) },
+	{ "ppp_dial_command", "clicked", G_CALLBACK (on_connection_modified) },
+	{ "ppp_volume", "value_changed", G_CALLBACK (on_connection_modified) },
+	{ "ppp_persist", "toggled", G_CALLBACK (on_connection_modified) },
+	{ "ppp_phone_number", "changed", G_CALLBACK (on_connection_modified) },
+	{ "ppp_external_line", "changed", G_CALLBACK (on_connection_modified) },
+	{ "ppp_login", "changed", G_CALLBACK (on_connection_modified) },
+	{ "ppp_password", "changed", G_CALLBACK (on_connection_modified) },
+	{ "ppp_ppp_options", "changed", G_CALLBACK (on_connection_modified) },
+	{ "ppp_stupid", "toggled", G_CALLBACK (on_connection_modified) },
+	{ "ppp_set_default_gw", "toggled", G_CALLBACK (on_connection_modified) },
+	{ "ppp_dns1", "changed", G_CALLBACK (on_connection_modified) },
+	{ "ppp_dns2", "changed", G_CALLBACK (on_connection_modified) },
 	{ NULL }
 };
 
 GstDialogSignal signals_after[] = {
-	{ "network_connection_other_page1",  "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_plip_page1",  "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_ppp_page1",    "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_ppp_page2",    "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_page_name",    "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ NULL }
-};
-
-static const GstWidgetPolicy policies[] = {
-	/* Name                      Basic                        Advanced           Require-Root   Default */
-	{ "connections_bbox",        GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "connection_delete",       GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },
-	{ "connection_configure",    GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },
-/*	{ "connection_activate",     GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },
-	{ "connection_deactivate",   GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },*/
-	{ "connection_def_gw_hbox",  GST_WIDGET_MODE_HIDDEN,      GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "statichost_table",        GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "statichost_add",          GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },
-	{ "statichost_delete",       GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },
-	{ "samba_use",               GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "description_label",       GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE, FALSE },
-	{ "smbdesc",                 GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE, FALSE },
-	{ "workgroup_label",         GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE, FALSE },
-	{ "workgroup",               GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE, FALSE },
-	{ "wins_use",       GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE, FALSE },
-/*	{ "samba_frame",             GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },*/
-	{ "winsserver",              GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },
-	{ "dns_table",               GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "domain",                  GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "domain_label",            GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "dns_list",                GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "dns_list_label",          GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "search_list",             GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "search_list_label",       GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "network_profiles_button", GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE, TRUE  },
+	{ "network_connection_page1", "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_page2", "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_wireless_page", "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_other_page1", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_plip_page1", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_ppp_page1", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_ppp_page2", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_page_name", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_page_finish", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
 	{ NULL }
 };
 
@@ -144,63 +167,9 @@ static GstReportHookEntry report_hooks[] = {
 	{ NULL,                      NULL,                           -1,                   FALSE, NULL }
 };
 
-static void
-update_notebook_complexity (GstTool *tool, GstDialogComplexity complexity)
-{
-	GtkWidget *hosts;
-	GtkNotebook *notebook;
-	gint pageno;
-
-	notebook = GTK_NOTEBOOK (gst_dialog_get_widget (tool->main_dialog, "network_admin_notebook"));
-	hosts    = gst_dialog_get_widget (tool->main_dialog, "hosts_container");
-	pageno   = gtk_notebook_page_num (notebook, hosts);
-
-	switch (complexity) {
-	case GST_DIALOG_BASIC:
-		g_return_if_fail (pageno != -1);
-
-		if (gtk_notebook_get_current_page (notebook) == pageno)
-			gtk_notebook_set_current_page (notebook, pageno - 1);
-		gtk_widget_ref (hosts);
-		gtk_widget_unparent (hosts);
-		gtk_notebook_remove_page (notebook, pageno);
-		break;
-	case GST_DIALOG_ADVANCED:
-		if (pageno != -1)
-			return;
-
-		gtk_notebook_append_page (notebook, hosts,
-					  gtk_label_new (_("Hosts")));
-		gtk_widget_unref (hosts);
-		break;
-	default:
-		g_warning ("update_notebook_complexity: Unsupported complexity.");
-	}
-}
-
-static void
-update_complexity (GstDialog *dialog, gpointer data)
-{
-	update_notebook_complexity (dialog->tool, dialog->complexity);
-	connection_update_complexity (dialog->tool, dialog->complexity);
-}
-
 static void
 connect_signals (GstDialog *main_dialog, GstDialogSignal *sigs, GstDialogSignal *sigs_after)
 {
-	GtkWidget *w;
-
-	g_signal_connect (G_OBJECT (main_dialog), "complexity_change",
-			  G_CALLBACK (update_complexity), NULL);
-
-	w = gst_dialog_get_widget (tool->main_dialog, "dns_list");
-	g_signal_connect (G_OBJECT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (w))),
-			  "changed", G_CALLBACK (gst_dialog_modify_cb), tool->main_dialog);
-
-	w = gst_dialog_get_widget (tool->main_dialog, "search_list");
-	g_signal_connect (G_OBJECT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (w))),
-			  "changed", G_CALLBACK (gst_dialog_modify_cb), tool->main_dialog);
-
 	gst_dialog_connect_signals (main_dialog, sigs);
 	gst_dialog_connect_signals_after (main_dialog, sigs_after);
 }
@@ -214,15 +183,17 @@ main (int argc, char *argv[])
 	gboolean wlan_connection = FALSE;
 	gboolean plip_connection = FALSE;
 	gboolean irlan_connection = FALSE;
+	gchar *interface = NULL;
 	
 	struct poptOption options[] =
 	{
-		{ "new-connection", '\0', 0, &connection, 0, _("Run the connection druid."), NULL },
-		{ "ppp-connection", '\0', 0, &ppp_connection, 0, _("Run the PPP connection druid."), NULL },
-		{ "eth-connection", '\0', 0, &eth_connection, 0, _("Run the ethernet connection druid."), NULL },
-		{ "wlan-connection", '\0', 0, &wlan_connection, 0, _("Run the wlan connection druid."), NULL },
-		{ "plip-connection", '\0', 0, &plip_connection, 0, _("Run the parallel port connection druid."), NULL },
-		{ "irlan-connection", '\0', 0, &irlan_connection, 0, _("Run the irlan connection druid."), NULL },
+		{ "new-connection", '\0', 0, &connection, 0, _("Run the connection assistant."), NULL },
+		{ "ppp-connection", '\0', 0, &ppp_connection, 0, _("Run the PPP connection assistant."), NULL },
+		{ "eth-connection", '\0', 0, &eth_connection, 0, _("Run the ethernet connection assistant."), NULL },
+		{ "wlan-connection", '\0', 0, &wlan_connection, 0, _("Run the wlan connection assistant."), NULL },
+		{ "plip-connection", '\0', 0, &plip_connection, 0, _("Run the parallel port connection assistant."), NULL },
+		{ "irlan-connection", '\0', 0, &irlan_connection, 0, _("Run the irlan connection assistant."), NULL },
+		{ "configure", '\0', POPT_ARG_STRING, &interface, 0, _("Configure a network interface"), _("interface") },
 		
 		{NULL, '\0', 0, NULL, 0}
 	};
@@ -250,15 +221,29 @@ main (int argc, char *argv[])
 		else if (irlan_connection)
 			type = GST_CONNECTION_IRLAN;
 
-		gst_tool_load_try (tool);
-
 		g_object_set_data (G_OBJECT (druid), "standalone", GINT_TO_POINTER (TRUE));
 
 		connect_signals (tool->main_dialog, signals, signals_after);
 		init_editable_filters (tool->main_dialog);
-		network_druid_new (druid, tool, type);
+		network_druid_new (druid, druid_window, tool, type);
 		gtk_widget_show_all (druid_window);
 
+		gst_tool_main_with_hidden_dialog (tool, FALSE);
+	} else if (interface != NULL) {
+		GtkWidget *window = gst_dialog_get_widget (tool->main_dialog, "connection_config_dialog");
+		GstConnection *connection;
+		xmlNodePtr root;
+
+		connect_signals (tool->main_dialog, signals, signals_after);
+		init_editable_filters (tool->main_dialog);
+
+		gst_tool_main_with_hidden_dialog (tool, TRUE);
+
+		g_object_set_data (G_OBJECT (window), "standalone", GINT_TO_POINTER (TRUE));
+		root = gst_xml_doc_get_root (tool->config);
+		transfer_misc_xml_to_tool (tool, root);
+		connection_configure_device (root, interface);
+
 		gtk_main ();
 	} else {
 		connect_signals (tool->main_dialog, signals, signals_after);
@@ -269,15 +254,19 @@ main (int argc, char *argv[])
 		gst_dialog_add_apply_hook (tool->main_dialog, callbacks_check_gateway_hook,      tool);
 		gst_tool_add_report_hooks (tool, report_hooks);
 		gst_tool_set_xml_funcs (tool, transfer_xml_to_gui, transfer_gui_to_xml, NULL);
-		gst_dialog_enable_complexity (tool->main_dialog);
-		gst_dialog_set_widget_policies (tool->main_dialog, policies);
 
-		init_hint_entries ();
 		init_editable_filters (tool->main_dialog);
 
 		on_network_admin_show (NULL, tool);
-		update_complexity (tool->main_dialog, NULL);
-		gst_tool_main (tool, FALSE);
+
+		gst_tool_main (tool, TRUE);
+		
+		if (connection_get_count (tool) == 0)
+			g_signal_emit_by_name (G_OBJECT (gst_dialog_get_widget (tool->main_dialog, "connection_add")),
+					       "clicked",
+					       NULL);
+
+		gtk_main ();
 	}
 		
 	return 0;
