@@ -29,6 +29,7 @@
 #include <libart_lgpl/art_filterlevel.h>
 
 #include "e-map.h"
+#include "e-map-marshal.h"
 
 /* Scroll step increment */
 
@@ -67,6 +68,10 @@ typedef struct
 	GtkAdjustment *hadj;
 	GtkAdjustment *vadj;
 
+	/* Signal ids for adjustments */
+	gulong hadj_signal_id;
+	gulong vadj_signal_id;
+
 	/* Current scrolling offsets */
 	int xofs, yofs;
 
@@ -102,7 +107,6 @@ static void e_map_realize (GtkWidget *widget);
 static void e_map_unrealize (GtkWidget *widget);
 static void e_map_size_request (GtkWidget *widget, GtkRequisition *requisition);
 static void e_map_size_allocate (GtkWidget *widget, GtkAllocation *allocation);
-static void e_map_draw (GtkWidget *widget, GdkRectangle *area);
 static gint e_map_button_press (GtkWidget *widget, GdkEventButton *event);
 static gint e_map_button_release (GtkWidget *widget, GdkEventButton *event);
 static gint e_map_motion (GtkWidget *widget, GdkEventMotion *event);
@@ -179,6 +183,7 @@ e_map_class_init (EMapClass *class)
 	GtkObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 
+	g_object_class = (GObjectClass*) class;
 	object_class = (GtkObjectClass *) class;
 	widget_class = (GtkWidgetClass *) class;
 
@@ -186,31 +191,33 @@ e_map_class_init (EMapClass *class)
 
 	object_class->destroy = e_map_destroy;
 	
-#warning FIXME
-#if 0
 	g_object_class->finalize = e_map_finalize;
-#endif
 
 	class->set_scroll_adjustments = e_map_set_scroll_adjustments;
 	widget_class->set_scroll_adjustments_signal =
 		g_signal_new ("set_scroll_adjustments",
-				G_OBJECT_CLASS_TYPE (object_class),
-				G_SIGNAL_RUN_LAST,
-				G_STRUCT_OFFSET (EMapClass, set_scroll_adjustments),
-				NULL, NULL,
-				g_cclosure_marshal_VOID__POINTER,
-				G_TYPE_NONE, 2,
-				GTK_TYPE_ADJUSTMENT, GTK_TYPE_ADJUSTMENT);
-
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EMapClass, set_scroll_adjustments),
+			      NULL, NULL,
+			      g_cclosure_user_marshal_VOID__OBJECT_OBJECT,
+			      G_TYPE_NONE, 2,
+			      GTK_TYPE_ADJUSTMENT, GTK_TYPE_ADJUSTMENT);
+/*	
+		g_signal_new ("set_scroll_adjustments",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EMapClass, set_scroll_adjustments),
+			      NULL, NULL,
+			      _gtk_marshal_VOID__OBJECT_OBJECT,
+			      G_TYPE_NONE, 2,
+			      GTK_TYPE_ADJUSTMENT, GTK_TYPE_ADJUSTMENT);
+*/
 	widget_class->unmap = e_map_unmap;
 	widget_class->realize = e_map_realize;
 	widget_class->unrealize = e_map_unrealize;
 	widget_class->size_request = e_map_size_request;
 	widget_class->size_allocate = e_map_size_allocate;
-#warning FIXME
-#if 0
-	widget_class->draw = e_map_draw;
-#endif
 	widget_class->button_press_event = e_map_button_press;
 	widget_class->button_release_event = e_map_button_release;
 	widget_class->motion_notify_event = e_map_motion;
@@ -254,8 +261,8 @@ e_map_destroy (GtkObject *object)
 	view = E_MAP (object);
 	priv = view->priv;
 
-	gtk_signal_disconnect_by_data (GTK_OBJECT (priv->hadj), view);
-	gtk_signal_disconnect_by_data (GTK_OBJECT (priv->vadj), view);
+	g_signal_handler_disconnect (G_OBJECT (priv->hadj), priv->hadj_signal_id);
+	g_signal_handler_disconnect (G_OBJECT (priv->vadj), priv->vadj_signal_id);
 
 	if (GTK_OBJECT_CLASS (parent_class)->destroy)
 		(*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
@@ -335,7 +342,7 @@ e_map_realize (GtkWidget *widget)
 	attr.height = widget->allocation.height;
 	attr.wclass = GDK_INPUT_OUTPUT;
 	attr.visual = gdk_rgb_get_visual ();
-	attr.colormap = gdk_rgb_get_cmap ();
+	attr.colormap = gdk_rgb_get_colormap ();
 	attr.event_mask = gtk_widget_get_events (widget) |
 	  GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS_MASK |
 	  GDK_POINTER_MOTION_MASK;
@@ -426,23 +433,6 @@ e_map_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 }
 
 
-/* Draw handler for the map view */
-
-static void
-e_map_draw (GtkWidget *widget, GdkRectangle *area)
-{
-	EMap *view;
-
-	g_return_if_fail (widget != NULL);
-	g_return_if_fail (IS_E_MAP (widget));
-	g_return_if_fail (area != NULL);
-
-	view = E_MAP (widget);
-
-	request_paint_area (view, area);
-}
-
-
 /* Button press handler for the map view */
 
 static gint
@@ -545,14 +535,14 @@ e_map_set_scroll_adjustments (GtkWidget *widget, GtkAdjustment *hadj, GtkAdjustm
 
 	if (priv->hadj && priv->hadj != hadj)
 	{
-		gtk_signal_disconnect_by_data (GTK_OBJECT (priv->hadj), view);
-		gtk_object_unref (GTK_OBJECT (priv->hadj));
+		g_signal_handler_disconnect (G_OBJECT (priv->hadj), priv->hadj_signal_id);
+		g_object_unref (G_OBJECT (priv->hadj));
 	}
 
 	if (priv->vadj && priv->vadj != vadj)
 	{
-		gtk_signal_disconnect_by_data (GTK_OBJECT (priv->vadj), view);
-		gtk_object_unref (GTK_OBJECT (priv->vadj));
+		g_signal_handler_disconnect (G_OBJECT (priv->vadj), priv->vadj_signal_id);
+		g_object_unref (G_OBJECT (priv->vadj));
 	}
 
 	need_adjust = FALSE;
@@ -560,10 +550,13 @@ e_map_set_scroll_adjustments (GtkWidget *widget, GtkAdjustment *hadj, GtkAdjustm
 	if (priv->hadj != hadj)
 	{
 		priv->hadj = hadj;
-		gtk_object_ref (GTK_OBJECT (priv->hadj));
+		g_object_ref (G_OBJECT (priv->hadj));
 		gtk_object_sink (GTK_OBJECT (priv->hadj));
 
-		gtk_signal_connect (GTK_OBJECT (priv->hadj), "value_changed", GTK_SIGNAL_FUNC (adjustment_changed_cb), view);
+		priv->hadj_signal_id = g_signal_connect (G_OBJECT (priv->hadj),
+							 "value_changed",
+							 G_CALLBACK (adjustment_changed_cb),
+							 view);
 
 		need_adjust = TRUE;
 	}
@@ -571,10 +564,13 @@ e_map_set_scroll_adjustments (GtkWidget *widget, GtkAdjustment *hadj, GtkAdjustm
 	if (priv->vadj != vadj)
 	{
 		priv->vadj = vadj;
-		gtk_object_ref (GTK_OBJECT (priv->vadj));
+		g_object_ref (G_OBJECT (priv->vadj));
 		gtk_object_sink (GTK_OBJECT (priv->vadj));
 
-		gtk_signal_connect (GTK_OBJECT (priv->vadj), "value_changed", GTK_SIGNAL_FUNC (adjustment_changed_cb), view);
+		priv->vadj_signal_id = g_signal_connect (G_OBJECT (priv->vadj),
+							 "value_changed",
+							 G_CALLBACK (adjustment_changed_cb),
+							 view);
 
 		need_adjust = TRUE;
 	}
@@ -638,17 +634,17 @@ e_map_key_press (GtkWidget *widget, GdkEventKey *event)
 
 		scroll_to (view, x, y);
 
-		gtk_signal_handler_block_by_data (GTK_OBJECT (priv->hadj), view);
-		gtk_signal_handler_block_by_data (GTK_OBJECT (priv->vadj), view);
+		g_signal_handler_block (G_OBJECT (priv->hadj), priv->hadj_signal_id);
+		g_signal_handler_block (G_OBJECT (priv->vadj), priv->vadj_signal_id);
 
 		priv->hadj->value = x;
 		priv->vadj->value = y;
 
-		gtk_signal_emit_by_name (GTK_OBJECT (priv->hadj), "value_changed");
-		gtk_signal_emit_by_name (GTK_OBJECT (priv->vadj), "value_changed");
+		g_signal_emit_by_name (GTK_OBJECT (priv->hadj), "value_changed");
+		g_signal_emit_by_name (GTK_OBJECT (priv->vadj), "value_changed");
 
-		gtk_signal_handler_unblock_by_data (GTK_OBJECT (priv->hadj), view);
-		gtk_signal_handler_unblock_by_data (GTK_OBJECT (priv->vadj), view);
+		g_signal_handler_unblock (G_OBJECT (priv->hadj), priv->hadj_signal_id);
+		g_signal_handler_unblock (G_OBJECT (priv->vadj), priv->vadj_signal_id);
 	}
 
 	return TRUE;
@@ -674,7 +670,7 @@ e_map_new ()
 {
 	GtkWidget *widget;
 
-	widget = GTK_WIDGET (gtk_type_new (TYPE_E_MAP));
+	widget = GTK_WIDGET (g_type_create_instance (TYPE_E_MAP));
 	return (E_MAP (widget));
 }
 
@@ -1337,9 +1333,9 @@ scroll_to (EMap *view, int x, int y)
 	gc = gdk_gc_new (window);
 	gdk_gc_set_exposures (gc, TRUE);
 
-	gdk_window_copy_area (window, gc, dest_x, dest_y, window, src_x, src_y, width - abs (xofs), height - abs (yofs));
+	gdk_draw_drawable (window, gc, window, src_x, src_y, dest_x, dest_y, width - abs (xofs), height - abs (yofs));
 
-	gdk_gc_destroy (gc);
+	gdk_gc_unref (gc);
 
 	/* Add the scrolled-in region */
 
@@ -1489,7 +1485,7 @@ blowup_window_area (GdkWindow *window, gint area_x, gint area_y, gint target_x,
 
 	/* Get area constraints */
 
-	gdk_window_get_size (window, &area_width, &area_height);
+	gdk_drawable_get_size (window, &area_width, &area_height);
 
 	/* Initialize area division array indexes */
 
@@ -1547,9 +1543,9 @@ blowup_window_area (GdkWindow *window, gint area_x, gint area_y, gint target_x,
 				/* Push left */
 
 				for (j = 0; j < zoom_chunk - 1; j++)
-					gdk_window_copy_area (window, gc, line + j + 1, 0, window, line, 0, 1, area_height);
+					gdk_draw_drawable (window, gc, window, line, 0, line + j +1, 0, 1, area_height);
 
-				gdk_window_copy_area (window, gc, 0, 0, window, zoom_chunk, 0, line, area_height);
+				gdk_draw_drawable (window, gc, window, zoom_chunk, 0, 0, 0, line, area_height);
 				if (line > target_x) target_x -= zoom_chunk;
 			}
 			else
@@ -1557,9 +1553,9 @@ blowup_window_area (GdkWindow *window, gint area_x, gint area_y, gint target_x,
 				/* Push right */
 
 				for (j = 0; j < zoom_chunk - 1; j++)
-					gdk_window_copy_area (window, gc, line + j - (zoom_chunk - 1), 0, window, line - zoom_chunk, 0, 1, area_height);
+					gdk_draw_drawable (window, gc, window, line - zoom_chunk, 0, line + j - (zoom_chunk - 1), 0, 1, area_height);
 
-				gdk_window_copy_area (window, gc, line, 0, window, line - zoom_chunk, 0, area_width - line, area_height);
+				gdk_draw_drawable (window, gc, window, line - zoom_chunk, 0, line, 0, area_width - line, area_height);
 				if (line < target_x) target_x += zoom_chunk;
 			}
 		}
@@ -1575,9 +1571,9 @@ blowup_window_area (GdkWindow *window, gint area_x, gint area_y, gint target_x,
 				/* Push up */
 
 				for (j = 0; j < zoom_chunk - 1; j++)
-					gdk_window_copy_area (window, gc, 0, line + j + 1, window, 0, line, area_width, 1);
+					gdk_draw_drawable (window, gc, window, 0, line, 0, line + j + 1, area_width, 1);
 
-				gdk_window_copy_area (window, gc, 0, 0, window, 0, zoom_chunk, area_width, line);
+				gdk_draw_drawable (window, gc, window, 0, zoom_chunk, 0, 0, area_width, line);
 				if (line > target_y) target_y -= zoom_chunk;
 			}
 			else
@@ -1585,9 +1581,9 @@ blowup_window_area (GdkWindow *window, gint area_x, gint area_y, gint target_x,
 				/* Push down */
 
 				for (j = 0; j < zoom_chunk - 1; j++)
-					gdk_window_copy_area (window, gc, 0, line + j - (zoom_chunk - 1), window, 0, line - zoom_chunk, area_width, 1);
+					gdk_draw_drawable (window, gc, window, 0, line - zoom_chunk, 0, line + j - (zoom_chunk - 1), area_width, 1);
 
-				gdk_window_copy_area (window, gc, 0, line, window, 0, line - zoom_chunk, area_width, area_height - line);
+				gdk_draw_drawable (window, gc, window, 0, line - zoom_chunk, 0, line, area_width, area_height - line);
 				if (line < target_y) target_y += zoom_chunk;
 			}
 		}
@@ -1600,7 +1596,7 @@ blowup_window_area (GdkWindow *window, gint area_x, gint area_y, gint target_x,
 
 	/* Free our GC */
 
-	gdk_gc_destroy (gc);
+	gdk_gc_unref (gc);
 }
 
 
@@ -1730,11 +1726,8 @@ zoom_do (EMap *map)
 
 	priv = map->priv;
 
-#warning FIXME
-#if 0
-	gtk_signal_handler_block_by_data (GTK_OBJECT (priv->hadj), map);
-	gtk_signal_handler_block_by_data (GTK_OBJECT (priv->vadj), map);
-#endif
+	g_signal_handler_block (G_OBJECT (priv->hadj), priv->hadj_signal_id);
+	g_signal_handler_block (G_OBJECT (priv->vadj), priv->vadj_signal_id);
 
 	if (priv->zoom_state == E_MAP_ZOOMING_IN)
 	{
@@ -1746,12 +1739,9 @@ zoom_do (EMap *map)
 		/* if (e_map_get_smooth_zoom(map)) zoom_out_smooth(map); */
 		zoom_out (map);
 	}
-  
-#warning FIXME
-#if 0
-	gtk_signal_handler_unblock_by_data (GTK_OBJECT (priv->hadj), map);
-	gtk_signal_handler_unblock_by_data (GTK_OBJECT (priv->vadj), map);
-#endif
+
+	g_signal_handler_unblock (G_OBJECT (priv->hadj), priv->hadj_signal_id);
+	g_signal_handler_unblock (G_OBJECT (priv->vadj), priv->vadj_signal_id);
 
 	set_scroll_area(map);
 }
@@ -1812,17 +1802,17 @@ set_scroll_area (EMap *view)
 	{
 		priv->hadj->value = priv->xofs;
 
-		gtk_signal_handler_block_by_data (GTK_OBJECT (priv->hadj), view);
-		gtk_signal_emit_by_name (GTK_OBJECT (priv->hadj), "value_changed");
-		gtk_signal_handler_unblock_by_data (GTK_OBJECT (priv->hadj), view);
+		g_signal_handler_block (G_OBJECT (priv->hadj), priv->hadj_signal_id);
+		g_signal_emit_by_name (GTK_OBJECT (priv->hadj), "value_changed");
+		g_signal_handler_unblock (G_OBJECT (priv->hadj), priv->hadj_signal_id);
 	}
 
 	if (priv->vadj->value != priv->yofs)
 	{
 		priv->vadj->value = priv->yofs;
 
-		gtk_signal_handler_block_by_data (GTK_OBJECT (priv->vadj), view);
-		gtk_signal_emit_by_name (GTK_OBJECT (priv->vadj), "value_changed");
-		gtk_signal_handler_unblock_by_data (GTK_OBJECT (priv->vadj), view);
+		g_signal_handler_block (G_OBJECT (priv->vadj), priv->vadj_signal_id);
+		g_signal_emit_by_name (GTK_OBJECT (priv->vadj), "value_changed");
+		g_signal_handler_unblock (G_OBJECT (priv->vadj), priv->vadj_signal_id);
 	}
 }
