@@ -26,10 +26,10 @@
 
 enum {
 	COL_USER_LOGIN,
-	COL_USER_UID,
 	COL_USER_HOME,
-	COL_USER_SHELL,
 	COL_USER_COMMENT,
+	COL_USER_UID,
+	COL_USER_SHELL,
 	COL_USER_GROUP,
 	COL_USER_POINTER,
 
@@ -57,9 +57,9 @@ struct UserTreeItem_
 	UserTreeItem *children;
 };
 
-void	construct_users_table		(void);
+void	create_users_table		(void);
 void	populate_users_table		(void);
-void	update_users_table_complexity	(XstDialogComplexity);
+void	update_users_table_complexity	(GstDialogComplexity);
 void	users_table_update_content	(void);
 
 #endif /* _USERS_TABLE_H */
